@@ -142,7 +142,8 @@ PlotACC <- function(ACC, sdates, toptitle = "", sizetit = 1, ytitle = "",
   }
 
   # Load the user parameters
-  oldpar <- par(no.readonly = TRUE)
+  oldpar <- par(unique(c('mai', 'mgp', 'cex', 'cex.lab', 'cex.axis', 'new', 
+                         names(userArgs))))
   on.exit(par(oldpar))
   par(userArgs)
 
