@@ -1038,7 +1038,7 @@ PlotEquiMap <- function(var, lon, lat, varu = NULL, varv = NULL,
   }
   plot.new()
   # Load the user parameters
-  oldpar <- par(no.readonly = TRUE)
+  oldpar <- par('mar', 'cex.main', 'cex.axis', 'mgp', no.readonly = TRUE)
   on.exit(par(oldpar))
   par(userArgs)
   par(mar = margins, cex.main = cex_title, cex.axis = cex_axes_labels,
