@@ -122,7 +122,7 @@ PlotMatrix <- function(var, brks = NULL, cols = NULL,
             width = 8 * figure.width, height = 5)
   }
   
-  oldpar <- par(no.readonly = TRUE)
+  oldpar <- par(unique(c('mar', 'fig', 'new')))
   on.exit(par(oldpar))
   
   if (!is.null(fileout)) {
