@@ -123,7 +123,7 @@ PlotSection <- function(var, horiz, depth, toptitle = '', sizetit = 1,
   }
 
   # Load the user parameters
-  oldpar <- par(no.readonly = TRUE)
+  oldpar <- par(unique(c('mar', 'cex', 'mgp', 'las', names(userArgs))))
   on.exit(par(oldpar))
   par(userArgs)
 
