@@ -602,7 +602,7 @@ PlotStereoMap <- function(var, lon, lat, varu = NULL, varv = NULL, latlims = c(6
     layout(matrix(1:2, ncol = 2, nrow = 1), widths = c(8, 2))
   }
   # Load the user parameters
-  oldpar <- par(no.readonly = TRUE)
+  oldpar <- par(unique(c('mar', 'las', 'lwd', 'xpd', names(userArgs))))
   on.exit(par(oldpar))
   par(userArgs)
   par(mar = margins, las = 0)
